@@ -1,28 +1,35 @@
 #' @rdname bi_open
 #' @name bi_open
-#' @title Bi open
+#' @title Bi Open
 #' @description
 #' This function opens an NetCDF file
 #' The file can be specified as a string to the filepath, in which
 #' case a NetCDF connection is opened, or directly as a NetCDF connection.
 #'
-#' @param x either a path to a NetCDF file, or a NetCDF connection created using \code{nc_open}, or a \code{\link{libbi}} object from which to read the output
-#' @param file file to open (out of "input", "init", "obs", "output"), if \code{x} is given as a \code{libbi} object; by default, will read output file
+#' @param x either a path to a NetCDF file, or a NetCDF connection created using
+#'   \code{nc_open}, or a \code{\link{libbi}} object from which to read the
+#'   output
+#' @param file file to open (out of "input", "init", "obs", "output"), if
+#'   \code{x} is given as a \code{libbi} object; by default, will read output
+#'   file
 #' @return an open NetCDF connection
 #' @importFrom ncdf4 nc_open
-bi_open <- function(x, file = "output")
-{
-  if (!missing(file) && class(x) != "libbi") {
-    warning("'file' given to 'bi_open' although 'x' is not a 'libbi' object; will be ignored")
+#' @keywords internal
+bi_open <- function(x, file = "output") {
+  if (!missing(file) && !inherits(x, "libbi")) {
+    warning(
+      "'file' given to 'bi_open' although 'x' is not a 'libbi' object; ",
+      "will be ignored"
+    )
   }
 
-  if (typeof(x) == "character"){
+  if (typeof(x) == "character") {
     nc <- nc_open(tools::file_path_as_absolute(x))
-  } else if (class(x) == "ncdf4") {
+  } else if (inherits(x, "ncdf4")) {
     nc <- x
-  } else if (class(x) == "libbi"){
+  } else if (inherits(x, "libbi")) {
     if (!(missing(file) || file == "output")) {
-      opt_name <- paste(file, "file", sep="-")
+      opt_name <- paste(file, "file", sep = "-")
       if (!(opt_name %in% names(x$options))) {
         stop("libbi object does not contain an '", file, "' file")
       }
