@@ -2,11 +2,13 @@
 #' @name option_list
 #' @title Convert string to option list
 #' @description
-#' This function is used to convert an option string into a list of options. If a list is given, it will be kept as is
+#' This function is used to convert an option string into a list of options. If
+#'   a list is given, it will be kept as is
 #'
 #' @param ... any number of strings to convert
 #' @return a list of options and values
-option_list <- function(...){
+#' @keywords internal
+option_list <- function(...) {
 
   options <- list()
 
@@ -44,35 +46,39 @@ option_list <- function(...){
       ## identify within-option conflicts
       conflicting <- intersect(string[["with"]], string[["without"]])
       if (length(conflicting) > 0) {
-        stop("Option given as 'with' and 'without': ",
-             paste(conflicting, collapse=", "))
+        stop(
+          "Option given as 'with' and 'without': ",
+          paste(conflicting, collapse = ", ")
+        )
       }
       if ("with" %in% names(string)) {
         with_list <- as.list(rep("", length(string[["with"]])))
-        names(with_list) <- paste("with", string[["with"]], sep="-")
+        names(with_list) <- paste("with", string[["with"]], sep = "-")
         ## remove existing 'without' options of the same name
         without_options <-
-          sub("^without-", "", grep("^without-", names(options), value=TRUE))
+          sub("^without-", "", grep("^without-", names(options), value = TRUE))
         existing <- intersect(without_options, string[["with"]])
-        options[paste("without", existing, sep="-")] <- NULL
+        options[paste("without", existing, sep = "-")] <- NULL
         ## add as strings
         string[["with"]] <- NULL
         string <- c(string, with_list)
       }
       if ("without" %in% names(string)) {
         without_list <- as.list(rep("", length(string[["without"]])))
-        names(without_list) <- paste("without", string[["without"]], sep="-")
+        names(without_list) <- paste("without", string[["without"]], sep = "-")
         ## remove existing 'with' options of the same name
-        with_options <- sub("^with-", "", grep("^with-", names(options), value=TRUE))
+        with_options <- sub(
+          "^with-", "", grep("^with-", names(options), value = TRUE)
+        )
         existing <- intersect(with_options, string[["without"]])
-        options[paste("with", existing, sep="-")] <- NULL
+        options[paste("with", existing, sep = "-")] <- NULL
         ## add as strings
         string[["without"]] <- NULL
         string <- c(string, without_list)
       }
       if ("dry" %in% names(string)) {
         dry_list <- as.list(rep("", length(string[["dry"]])))
-        names(dry_list) <- paste("dry", string[["dry"]], sep="-")
+        names(dry_list) <- paste("dry", string[["dry"]], sep = "-")
         string[["dry"]] <- NULL
         string <- c(string, dry_list)
       }
@@ -89,36 +95,43 @@ option_list <- function(...){
 #' @name option_string
 #' @title Convert Options
 #' @description
-#' This function is used to convert a list of options into an options string. If a string is given,  it will be taken as such.
+#' This function is used to convert a list of options into an options string. If
+#'   a string is given,  it will be taken as such.
 #'
-#' @param ... any number of lists of options, or strings (which will be left unmodified). If lists are given, later arguments will override earlier ones
+#' @param ... any number of lists of options, or strings (which will be left
+#'   unmodified). If lists are given, later arguments will override earlier ones
 #
-option_string <- function(...){
+#' @keywords internal
+option_string <- function(...) {
   list_options <- list()
 
   for (option in list(...)) list_options[names(option)] <- option
 
-  string <- lapply(names(list_options),
-                   function(option) {
-                       if (is.logical(list_options[[option]])) {
-                           if (option == "verbose") {
-                               return("--verbose")
-                           } else {
-                               if (list_options[[option]] == TRUE)
-                                   return(paste0("--enable-", option))
-                               else
-                                   return(paste0("--disable-", option))
-                           }
-                       } else {
-                           ret <- c(paste0("--", option))
-                           value <- list_options[[option]]
-                           if (length(value) == 0 || value != "") {
-                               ret <- c(ret, format(list_options[[option]],
-                                                    scientific = FALSE))
-                           }
-                           return(ret)
-                       }
-                   })
+  string <- lapply(
+    names(list_options),
+    function(option) {
+      if (is.logical(list_options[[option]])) {
+        if (option == "verbose") {
+          return("--verbose")
+        } else {
+          if (list_options[[option]] == TRUE) {
+            return(paste0("--enable-", option))
+          } else {
+            return(paste0("--disable-", option))
+          }
+        }
+      } else {
+        ret <- c(paste0("--", option))
+        value <- list_options[[option]]
+        if (length(value) == 0 || value != "") {
+          ret <- c(ret, format(list_options[[option]],
+            scientific = FALSE
+          ))
+        }
+        return(ret)
+      }
+    }
+  )
 
   return(unlist(string))
 }
